@@ -78,11 +78,7 @@
  *   </listitem>
  *
  *   <listitem>
- *     URLs with queries ("?") or fragment identifiers ("#") are not allowed.
- *   </listitem>
- *
- *   <listitem>
- *     All other URL schemes other than data: in references require a base URL.  For
+ *     All other URL schemes in references require a base URL.  For
  *     example, this means that if you load an SVG with
  *     rsvg_handle_new_from_data() without calling rsvg_handle_set_base_uri(),
  *     then any referenced files will not be allowed (e.g. raster images to be
@@ -337,8 +333,6 @@ extern void rsvg_rust_handle_set_dpi_y (RsvgHandle *raw_handle, double dpi_y);
 extern void rsvg_rust_handle_set_base_url (RsvgHandle *raw_handle, const char *uri);
 extern void rsvg_rust_handle_set_base_gfile (RsvgHandle *raw_handle, GFile *file);
 extern const char *rsvg_rust_handle_get_base_url (RsvgHandle *raw_handle);
-extern guint rsvg_rust_handle_get_flags (RsvgHandle *raw_handle);
-extern void rsvg_rust_handle_set_flags (RsvgHandle *raw_handle, guint flags);
 extern guint rsvg_rust_handle_set_testing (RsvgHandle *raw_handle, gboolean testing);
 extern gboolean rsvg_rust_handle_read_stream_sync (RsvgHandle *handle,
                                                    GInputStream *stream,
