@@ -16,64 +16,6 @@
 //! * Get an [`SvgHandle`] from the [`Loader`].
 //! * Create a [`CairoRenderer`] for the [`SvgHandle`] and render to a Cairo context.
 //!
-//! You can put the following in your `Cargo.toml`:
-//!
-//! ```toml
-//! [dependencies]
-//! librsvg = { git="https://gitlab.gnome.org/GNOME/librsvg" }
-//! cairo-rs = "0.7.0"
-//! glib = "0.8.0"                                    # only if you need streams
-//! gio = { version="0.7.0", features=["v2_48"] }     # likewise
-//! ```
-//!
-//! # Example
-//!
-//! ```
-//! use cairo;
-//! use gio;
-//! use glib;
-//!
-//! const WIDTH: i32 = 640;
-//! const HEIGHT: i32 = 480;
-//!
-//! fn main() {
-//!     // Loading from a file
-//!
-//!     let handle = librsvg::Loader::new().read_path("example.svg").unwrap();
-//!
-//!     let surface = cairo::ImageSurface::create(cairo::Format::ARgb32, WIDTH, HEIGHT).unwrap();
-//!     let cr = cairo::Context::new(&surface);
-//!
-//!     let renderer = librsvg::CairoRenderer::new(&handle);
-//!     renderer.render_document(
-//!         &cr,
-//!         &cairo::Rectangle {
-//!             x: 0.0,
-//!             y: 0.0,
-//!             width: f64::from(WIDTH),
-//!             height: f64::from(HEIGHT),
-//!         },
-//!     ).unwrap();
-//!
-//!     // Loading from a static SVG asset
-//!
-//!     let bytes = glib::Bytes::from_static(
-//!         br#"<?xml version="1.0" encoding="UTF-8"?>
-//!             <svg xmlns="http://www.w3.org/2000/svg" width="50" height="50">
-//!                 <rect id="foo" x="10" y="10" width="30" height="30"/>
-//!             </svg>
-//!         "#
-//!     );
-//!     let stream = gio::MemoryInputStream::new_from_bytes(&bytes);
-//!
-//!     let handle = librsvg::Loader::new().read_stream(
-//!         &stream,
-//!         None::<&gio::File>,          // no base file as this document has no references
-//!         None::<&gio::Cancellable>,   // no cancellable
-//!     ).unwrap();
-//! }
-//! ```
-//!
 //! [`Loader`]: struct.Loader.html
 //! [`SvgHandle`]: struct.SvgHandle.html
 //! [`CairoRenderer`]: struct.CairoRenderer.html
@@ -101,7 +43,7 @@
 //! `/foo/bar/baz.svg`, then librsvg will only try to load referenced
 //! files (from SVG's `<image>` element, for example, or from content
 //! included through XML entities) if those files are in `/foo/bar/*`
-//! or in `/foo/bar/*/.../*`.  This is so that malicious SVG files
+//! or in `/foo/bar/*/.../*`.  This is so that malicious SVG documents
 //! cannot include files that are in a directory above.
 //!
 //! The full set of rules for deciding which URLs may be loaded is as follows;
@@ -155,19 +97,19 @@ use std::path::Path;
 
 use gio::{Cancellable, FileExt};
 
-use rsvg_internals::{Dpi, Handle};
+use rsvg_internals::{Dpi, Handle, LoadOptions};
 
 pub use rsvg_internals::{
     DefsLookupErrorKind,
     HrefError,
-    Length,
+    Length as InternalLength,
     LengthUnit,
-    LoadOptions,
     LoadingError,
     RenderingError,
+    RsvgLength as Length,
 };
 
-/// Struct for loading an [`SvgHandle`][SvgHandle].
+/// Builder for loading an [`SvgHandle`][SvgHandle].
 ///
 /// This is the starting point for using librsvg.  This struct
 /// implements a builder pattern for configuring an
@@ -186,7 +128,7 @@ impl Loader {
     /// Creates a `Loader` with the default flags.
     ///
     /// * [`unlimited_size`](#method.with_unlimited_size) defaults to `false`, as malicious
-    /// SVG files could cause the XML parser to consume very large amounts of memory.
+    /// SVG documents could cause the XML parser to consume very large amounts of memory.
     ///
     /// * [`keep_image_data`](#method.keep_image_data) defaults to
     /// `false`.  You may only need this if rendering to Cairo
@@ -236,7 +178,7 @@ impl Loader {
     ///
     /// Normally, Cairo expects one to pass it uncompressed (decoded)
     /// images as surfaces.  However, when using a PDF rendering
-    /// context to render SVG files that reference raster images
+    /// context to render SVG documents that reference raster images
     /// (e.g. those which include a bitmap as part of the SVG image),
     /// it may be more efficient to embed the original, compressed raster
     /// images into the PDF.
@@ -271,7 +213,7 @@ impl Loader {
         self
     }
 
-    /// Reads an SVG file from `path`.
+    /// Reads an SVG document from `path`.
     ///
     /// # Example:
     ///
@@ -287,7 +229,7 @@ impl Loader {
         self.read_file(&file, None::<&Cancellable>)
     }
 
-    /// Reads an SVG file from a `gio::File`.
+    /// Reads an SVG document from a `gio::File`.
     ///
     /// The `cancellable` can be used to cancel loading from another thread.
     ///
@@ -315,7 +257,7 @@ impl Loader {
     /// takes a `gio::InputStream`.  The `base_file`, if it is not
     /// `None`, is used to extract the base URL for this stream.
     ///
-    /// Reading an SVG file may involve resolving relative URLs if the
+    /// Reading an SVG document may involve resolving relative URLs if the
     /// SVG references things like raster images, or other SVG files.
     /// In this case, pass the `base_file` that correspondds to the
     /// URL where this SVG got loaded from.
@@ -397,18 +339,39 @@ const DEFAULT_DPI_X: f64 = 96.0;
 const DEFAULT_DPI_Y: f64 = 96.0;
 
 #[derive(Debug, Copy, Clone, PartialEq)]
+/// Contains the values of the `<svg>` element's `width`, `height`, and `viewBox` attributes.
+///
+/// An SVG document has a toplevel `<svg>` element, with optional attributes `width`,
+/// `height`, and `viewBox`.  This structure contains the values for those attributes; you
+/// can obtain the struct from [`CairoRenderer::intrinsic_dimensions`].
+///
+/// As an example, the following SVG element has a `width` of 100 pixels
+/// and a `height` of 400 pixels, but no `viewBox`.
+///
+/// ```xml
+/// <svg xmlns="http://www.w3.org/2000/svg" width="100" height="400">
+/// ```
+/// In this case, the length fields will be set to `Some()`, and `vbox` to `None`.
+///
+/// [`CairoRenderer::intrinsic_dimensions`]: struct.CairoRenderer.html#method.intrinsic_dimensions
 pub struct IntrinsicDimensions {
+    /// `width` attribute of the `<svg>`, if present
     pub width: Option<Length>,
+
+    /// `height` attribute of the `<svg>`, if present
     pub height: Option<Length>,
+
+    /// `viewBox` attribute of the `<svg>`, if present
     pub vbox: Option<cairo::Rectangle>,
 }
 
 impl<'a> CairoRenderer<'a> {
     /// Creates a `CairoRenderer` for the specified `SvgHandle`.
     ///
-    /// If an SVG file has physical units like `5cm`, they must be resolved
-    /// to pixel-based values.  The default pixel density is `96.0` DPI in
-    /// both dimensions.
+    /// The default dots-per-inch (DPI) value is set to 96; you can change it
+    /// with the [`with_dpi`] method.
+    ///
+    /// [`with_dpi`]: #method.with_dpi
     pub fn new(handle: &'a SvgHandle) -> Self {
         CairoRenderer {
             handle,
@@ -417,6 +380,10 @@ impl<'a> CairoRenderer<'a> {
     }
 
     /// Configures the dots-per-inch for resolving physical lengths.
+    ///
+    /// If an SVG document has physical units like `5cm`, they must be resolved
+    /// to pixel-based values.  The default pixel density is 96 DPI in
+    /// both dimensions.
     pub fn with_dpi(self, dpi_x: f64, dpi_y: f64) -> Self {
         assert!(dpi_x > 0.0);
         assert!(dpi_y > 0.0);
@@ -427,12 +394,19 @@ impl<'a> CairoRenderer<'a> {
         }
     }
 
+    /// Queries the `width`, `height`, and `viewBox` attributes in an SVG document.
+    ///
+    /// If you are calling this function to compute a scaling factor to render the SVG,
+    /// consider simply using [`render_document`] instead; it will do the scaling
+    /// computations automatically.
+    ///
+    /// [`render_document`]: #method.render_document
     pub fn intrinsic_dimensions(&self) -> IntrinsicDimensions {
         let d = self.handle.0.get_intrinsic_dimensions();
 
         IntrinsicDimensions {
-            width: d.width.map(|l| l.to_length()),
-            height: d.height.map(|l| l.to_length()),
+            width: d.width.map(Into::into),
+            height: d.height.map(Into::into),
             vbox: d.vbox.map(|v| cairo::Rectangle {
                 x: v.x,
                 y: v.y,
