@@ -8,7 +8,8 @@ use crate::bbox::BoundingBox;
 use crate::coord_units::CoordUnits;
 use crate::drawing_ctx::DrawingCtx;
 use crate::error::{RenderingError, ValueErrorKind};
-use crate::length::{LengthHorizontal, LengthUnit, LengthVertical};
+use crate::filter::Filter;
+use crate::length::*;
 use crate::node::{CascadedValues, NodeResult, NodeTrait, NodeType, RsvgNode};
 use crate::parsers::{ParseError, ParseValue};
 use crate::properties::ComputedValues;
@@ -28,11 +29,8 @@ use self::error::FilterError;
 mod input;
 use self::input::Input;
 
-pub mod node;
-use self::node::NodeFilter;
-
 /// A filter primitive interface.
-pub trait Filter: NodeTrait {
+pub trait FilterEffect: NodeTrait {
     /// Renders this filter primitive.
     ///
     /// If this filter primitive can't be rendered for whatever reason (for instance, a required
@@ -52,9 +50,9 @@ pub trait Filter: NodeTrait {
     fn is_affected_by_color_interpolation_filters(&self) -> bool;
 }
 
-macro_rules! impl_node_as_filter {
+macro_rules! impl_node_as_filter_effect {
     () => (
-        fn as_filter(&self) -> Option<&dyn Filter> {
+        fn as_filter_effect(&self) -> Option<&dyn FilterEffect> {
             Some(self)
         }
     )
@@ -78,10 +76,10 @@ pub mod turbulence;
 
 /// The base filter primitive node containing common properties.
 struct Primitive {
-    x: Option<LengthHorizontal>,
-    y: Option<LengthVertical>,
-    width: Option<LengthHorizontal>,
-    height: Option<LengthVertical>,
+    x: Option<Length<Horizontal>>,
+    y: Option<Length<Vertical>>,
+    width: Option<Length<Horizontal>>,
+    height: Option<Length<Vertical>>,
     result: Option<String>,
 }
 
@@ -94,7 +92,7 @@ struct PrimitiveWithInput {
 impl Primitive {
     /// Constructs a new `Primitive` with empty properties.
     #[inline]
-    fn new<T: Filter>() -> Primitive {
+    fn new<T: FilterEffect>() -> Primitive {
         Primitive {
             x: None,
             y: None,
@@ -117,7 +115,7 @@ impl NodeTrait for Primitive {
         let primitiveunits = parent
             .and_then(|parent| {
                 if parent.borrow().get_type() == NodeType::Filter {
-                    Some(parent.borrow().get_impl::<NodeFilter>().get_primitive_units())
+                    Some(parent.borrow().get_impl::<Filter>().get_primitive_units())
                 } else {
                     None
                 }
@@ -126,12 +124,12 @@ impl NodeTrait for Primitive {
 
         let no_units_allowed = primitiveunits == CoordUnits::ObjectBoundingBox;
 
-        let check_units_horizontal = |length: LengthHorizontal| {
+        let check_units_horizontal = |length: Length<Horizontal>| {
             if !no_units_allowed {
                 return Ok(length);
             }
 
-            match length.unit() {
+            match length.unit {
                 LengthUnit::Px | LengthUnit::Percent => Ok(length),
                 _ => Err(ValueErrorKind::Parse(ParseError::new(
                     "unit identifiers are not allowed with primitiveUnits set to objectBoundingBox",
@@ -139,12 +137,12 @@ impl NodeTrait for Primitive {
             }
         };
 
-        let check_units_vertical = |length: LengthVertical| {
+        let check_units_vertical = |length: Length<Vertical>| {
             if !no_units_allowed {
                 return Ok(length);
             }
 
-            match length.unit() {
+            match length.unit {
                 LengthUnit::Px | LengthUnit::Percent => Ok(length),
                 _ => Err(ValueErrorKind::Parse(ParseError::new(
                     "unit identifiers are not allowed with primitiveUnits set to objectBoundingBox",
@@ -152,12 +150,12 @@ impl NodeTrait for Primitive {
             }
         };
 
-        let check_units_horizontal_and_ensure_nonnegative = |length: LengthHorizontal| {
-            check_units_horizontal(length).and_then(LengthHorizontal::check_nonnegative)
+        let check_units_horizontal_and_ensure_nonnegative = |length: Length<Horizontal>| {
+            check_units_horizontal(length).and_then(Length::<Horizontal>::check_nonnegative)
         };
 
-        let check_units_vertical_and_ensure_nonnegative = |length: LengthVertical| {
-            check_units_vertical(length).and_then(LengthVertical::check_nonnegative)
+        let check_units_vertical_and_ensure_nonnegative = |length: Length<Vertical>| {
+            check_units_vertical(length).and_then(Length::<Vertical>::check_nonnegative)
         };
 
         for (attr, value) in pbag.iter() {
@@ -194,7 +192,7 @@ impl NodeTrait for Primitive {
 impl PrimitiveWithInput {
     /// Constructs a new `PrimitiveWithInput` with empty properties.
     #[inline]
-    fn new<T: Filter>() -> PrimitiveWithInput {
+    fn new<T: FilterEffect>() -> PrimitiveWithInput {
         PrimitiveWithInput {
             base: Primitive::new::<T>(),
             in_: None,
@@ -297,7 +295,7 @@ pub fn render(
             !in_error
         })
         // Keep only filter primitives (those that implement the Filter trait)
-        .filter(|c| c.borrow().get_node_trait().as_filter().is_some())
+        .filter(|c| c.borrow().get_node_trait().as_filter_effect().is_some())
         // Check if the node wants linear RGB.
         .map(|c| {
             let linear_rgb = {
@@ -312,7 +310,7 @@ pub fn render(
 
     for (c, linear_rgb) in primitives {
         let node_data = c.borrow();
-        let filter = node_data.get_node_trait().as_filter().unwrap();
+        let filter = node_data.get_node_trait().as_filter_effect().unwrap();
 
         let mut render = |filter_ctx: &mut FilterContext| {
             if let Err(err) = filter
