@@ -6,32 +6,32 @@ use crate::property_bag::PropertyBag;
 use crate::surface_utils::shared_surface::SharedImageSurface;
 
 use super::context::{FilterContext, FilterInput, FilterOutput, FilterResult};
-use super::{Filter, FilterError, PrimitiveWithInput};
+use super::{FilterEffect, FilterError, PrimitiveWithInput};
 
 /// The `feTile` filter primitive.
-pub struct Tile {
+pub struct FeTile {
     base: PrimitiveWithInput,
 }
 
-impl Default for Tile {
+impl Default for FeTile {
     /// Constructs a new `Tile` with empty properties.
     #[inline]
-    fn default() -> Tile {
-        Tile {
+    fn default() -> FeTile {
+        FeTile {
             base: PrimitiveWithInput::new::<Self>(),
         }
     }
 }
 
-impl NodeTrait for Tile {
-    impl_node_as_filter!();
+impl NodeTrait for FeTile {
+    impl_node_as_filter_effect!();
 
     fn set_atts(&mut self, parent: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         self.base.set_atts(parent, pbag)
     }
 }
 
-impl Filter for Tile {
+impl FilterEffect for FeTile {
     fn render(
         &self,
         _node: &RsvgNode,
