@@ -123,7 +123,7 @@ fn fix_focus_point(fx: f64, fy: f64, cx: f64, cy: f64, radius: f64) -> (f64, f64
 
 /// Node for the <stop> element
 #[derive(Default)]
-pub struct NodeStop {
+pub struct Stop {
     /// <stop offset="..."/>
     offset: UnitInterval,
 
@@ -131,8 +131,8 @@ pub struct NodeStop {
     // they go into property_defs.rs
 }
 
-fn validate_offset(length: LengthBoth) -> Result<LengthBoth, ValueErrorKind> {
-    match length.unit() {
+fn validate_offset(length: Length<Both>) -> Result<Length<Both>, ValueErrorKind> {
+    match length.unit {
         LengthUnit::Px | LengthUnit::Percent => Ok(length),
         _ => Err(ValueErrorKind::Value(
             "stop offset must be in default or percent units".to_string(),
@@ -140,14 +140,14 @@ fn validate_offset(length: LengthBoth) -> Result<LengthBoth, ValueErrorKind> {
     }
 }
 
-impl NodeTrait for NodeStop {
+impl NodeTrait for Stop {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
                 expanded_name!(svg "offset") => {
                     self.offset = attr
                         .parse_and_validate(value, validate_offset)
-                        .map(|l| UnitInterval::clamp(l.length()))?
+                        .map(|l| UnitInterval::clamp(l.length))?
                 }
                 _ => (),
             }
@@ -164,18 +164,18 @@ impl NodeTrait for NodeStop {
 #[derive(Copy, Clone)]
 enum UnresolvedVariant {
     Linear {
-        x1: Option<LengthHorizontal>,
-        y1: Option<LengthVertical>,
-        x2: Option<LengthHorizontal>,
-        y2: Option<LengthVertical>,
+        x1: Option<Length<Horizontal>>,
+        y1: Option<Length<Vertical>>,
+        x2: Option<Length<Horizontal>>,
+        y2: Option<Length<Vertical>>,
     },
 
     Radial {
-        cx: Option<LengthHorizontal>,
-        cy: Option<LengthVertical>,
-        r: Option<LengthBoth>,
-        fx: Option<LengthHorizontal>,
-        fy: Option<LengthVertical>,
+        cx: Option<Length<Horizontal>>,
+        cy: Option<Length<Vertical>>,
+        r: Option<Length<Both>>,
+        fx: Option<Length<Horizontal>>,
+        fy: Option<Length<Vertical>>,
     },
 }
 
@@ -183,18 +183,18 @@ enum UnresolvedVariant {
 #[derive(Clone)]
 enum Variant {
     Linear {
-        x1: LengthHorizontal,
-        y1: LengthVertical,
-        x2: LengthHorizontal,
-        y2: LengthVertical,
+        x1: Length<Horizontal>,
+        y1: Length<Vertical>,
+        x2: Length<Horizontal>,
+        y2: Length<Vertical>,
     },
 
     Radial {
-        cx: LengthHorizontal,
-        cy: LengthVertical,
-        r: LengthBoth,
-        fx: LengthHorizontal,
-        fy: LengthVertical,
+        cx: Length<Horizontal>,
+        cy: Length<Vertical>,
+        r: Length<Both>,
+        fx: Length<Horizontal>,
+        fy: Length<Vertical>,
     },
 }
 
@@ -260,16 +260,16 @@ impl UnresolvedVariant {
     fn resolve_from_defaults(&self) -> UnresolvedVariant {
         match self {
             UnresolvedVariant::Linear { x1, y1, x2, y2 } => UnresolvedVariant::Linear {
-                x1: x1.or_else(|| Some(LengthHorizontal::parse_str("0%").unwrap())),
-                y1: y1.or_else(|| Some(LengthVertical::parse_str("0%").unwrap())),
-                x2: x2.or_else(|| Some(LengthHorizontal::parse_str("100%").unwrap())),
-                y2: y2.or_else(|| Some(LengthVertical::parse_str("0%").unwrap())),
+                x1: x1.or_else(|| Some(Length::<Horizontal>::parse_str("0%").unwrap())),
+                y1: y1.or_else(|| Some(Length::<Vertical>::parse_str("0%").unwrap())),
+                x2: x2.or_else(|| Some(Length::<Horizontal>::parse_str("100%").unwrap())),
+                y2: y2.or_else(|| Some(Length::<Vertical>::parse_str("0%").unwrap())),
             },
 
             UnresolvedVariant::Radial { cx, cy, r, fx, fy } => {
-                let cx = cx.or_else(|| Some(LengthHorizontal::parse_str("50%").unwrap()));
-                let cy = cy.or_else(|| Some(LengthVertical::parse_str("50%").unwrap()));
-                let r = r.or_else(|| Some(LengthBoth::parse_str("50%").unwrap()));
+                let cx = cx.or_else(|| Some(Length::<Horizontal>::parse_str("50%").unwrap()));
+                let cy = cy.or_else(|| Some(Length::<Vertical>::parse_str("50%").unwrap()));
+                let r = r.or_else(|| Some(Length::<Both>::parse_str("50%").unwrap()));
 
                 // fx and fy fall back to the presentational value of cx and cy
                 let fx = fx.or(cx);
@@ -326,25 +326,25 @@ struct Common {
 
 /// Node for the <linearGradient> element
 #[derive(Default)]
-pub struct NodeLinearGradient {
+pub struct LinearGradient {
     common: Common,
 
-    x1: Option<LengthHorizontal>,
-    y1: Option<LengthVertical>,
-    x2: Option<LengthHorizontal>,
-    y2: Option<LengthVertical>,
+    x1: Option<Length<Horizontal>>,
+    y1: Option<Length<Vertical>>,
+    x2: Option<Length<Horizontal>>,
+    y2: Option<Length<Vertical>>,
 }
 
 /// Node for the <radialGradient> element
 #[derive(Default)]
-pub struct NodeRadialGradient {
+pub struct RadialGradient {
     common: Common,
 
-    cx: Option<LengthHorizontal>,
-    cy: Option<LengthVertical>,
-    r: Option<LengthBoth>,
-    fx: Option<LengthHorizontal>,
-    fy: Option<LengthVertical>,
+    cx: Option<Length<Horizontal>>,
+    cy: Option<Length<Vertical>>,
+    r: Option<Length<Both>>,
+    fx: Option<Length<Horizontal>>,
+    fy: Option<Length<Vertical>>,
 }
 
 /// Main structure used during gradient resolution.  For unresolved
@@ -452,7 +452,7 @@ impl UnresolvedGradient {
                 continue;
             }
 
-            let stop = child.get_impl::<NodeStop>();
+            let stop = child.get_impl::<Stop>();
 
             if child.is_in_error() {
                 rsvg_log!("(not using gradient stop {} because it is in error)", child);
@@ -508,7 +508,7 @@ struct Unresolved {
     fallback: Option<Fragment>,
 }
 
-impl NodeLinearGradient {
+impl LinearGradient {
     fn get_unresolved_variant(&self) -> UnresolvedVariant {
         UnresolvedVariant::Linear {
             x1: self.x1,
@@ -519,7 +519,7 @@ impl NodeLinearGradient {
     }
 }
 
-impl NodeRadialGradient {
+impl RadialGradient {
     fn get_unresolved_variant(&self) -> UnresolvedVariant {
         UnresolvedVariant::Radial {
             cx: self.cx,
@@ -553,8 +553,8 @@ macro_rules! impl_get_unresolved {
         }
     }
 }
-impl_get_unresolved!(NodeLinearGradient);
-impl_get_unresolved!(NodeRadialGradient);
+impl_get_unresolved!(LinearGradient);
+impl_get_unresolved!(RadialGradient);
 
 impl Common {
     fn set_atts(&mut self, pbag: &PropertyBag<'_>) -> NodeResult {
@@ -574,7 +574,7 @@ impl Common {
     }
 }
 
-impl NodeTrait for NodeLinearGradient {
+impl NodeTrait for LinearGradient {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         self.common.set_atts(pbag)?;
 
@@ -593,7 +593,7 @@ impl NodeTrait for NodeLinearGradient {
     }
 }
 
-impl NodeTrait for NodeRadialGradient {
+impl NodeTrait for RadialGradient {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         self.common.set_atts(pbag)?;
 
@@ -677,16 +677,16 @@ macro_rules! impl_paint_source {
 }
 
 impl_paint_source!(
-    NodeLinearGradient,
+    LinearGradient,
     NodeType::LinearGradient,
-    NodeRadialGradient,
+    RadialGradient,
     NodeType::RadialGradient,
 );
 
 impl_paint_source!(
-    NodeRadialGradient,
+    RadialGradient,
     NodeType::RadialGradient,
-    NodeLinearGradient,
+    LinearGradient,
     NodeType::LinearGradient,
 );
 
@@ -826,11 +826,11 @@ mod tests {
             &QualName::new(None, ns!(svg), local_name!("linearGradient")),
             None,
             None,
-            Box::new(NodeLinearGradient::default())
+            Box::new(LinearGradient::default())
         ));
 
         let borrow = node.borrow();
-        let g = borrow.get_impl::<NodeLinearGradient>();
+        let g = borrow.get_impl::<LinearGradient>();
         let Unresolved { gradient, .. } = g.get_unresolved(&node);
         let gradient = gradient.resolve_from_defaults();
         assert!(gradient.is_resolved());
@@ -840,11 +840,11 @@ mod tests {
             &QualName::new(None, ns!(svg), local_name!("radialGradient")),
             None,
             None,
-            Box::new(NodeRadialGradient::default())
+            Box::new(RadialGradient::default())
         ));
 
         let borrow = node.borrow();
-        let g = borrow.get_impl::<NodeRadialGradient>();
+        let g = borrow.get_impl::<RadialGradient>();
         let Unresolved { gradient, .. } = g.get_unresolved(&node);
         let gradient = gradient.resolve_from_defaults();
         assert!(gradient.is_resolved());
