@@ -13,7 +13,7 @@ use crate::drawing_ctx::DrawingCtx;
 use crate::error::*;
 use crate::float_eq_cairo::ApproxEqCairo;
 use crate::iri::IRI;
-use crate::length::{LengthHorizontal, LengthVertical};
+use crate::length::*;
 use crate::node::*;
 use crate::parsers::{Parse, ParseError, ParseValue};
 use crate::path_builder::*;
@@ -88,26 +88,26 @@ impl Parse for MarkerOrient {
     }
 }
 
-pub struct NodeMarker {
+pub struct Marker {
     units: MarkerUnits,
-    ref_x: LengthHorizontal,
-    ref_y: LengthVertical,
-    width: LengthHorizontal,
-    height: LengthVertical,
+    ref_x: Length<Horizontal>,
+    ref_y: Length<Vertical>,
+    width: Length<Horizontal>,
+    height: Length<Vertical>,
     orient: MarkerOrient,
     aspect: AspectRatio,
     vbox: Option<ViewBox>,
 }
 
-impl Default for NodeMarker {
-    fn default() -> NodeMarker {
-        NodeMarker {
+impl Default for Marker {
+    fn default() -> Marker {
+        Marker {
             units: MarkerUnits::default(),
             ref_x: Default::default(),
             ref_y: Default::default(),
             // the following two are per the spec
-            width: LengthHorizontal::parse_str("3").unwrap(),
-            height: LengthVertical::parse_str("3").unwrap(),
+            width: Length::<Horizontal>::parse_str("3").unwrap(),
+            height: Length::<Vertical>::parse_str("3").unwrap(),
             orient: MarkerOrient::default(),
             aspect: AspectRatio::default(),
             vbox: None,
@@ -115,7 +115,7 @@ impl Default for NodeMarker {
     }
 }
 
-impl NodeMarker {
+impl Marker {
     fn render(
         &self,
         node: &RsvgNode,
@@ -193,7 +193,7 @@ impl NodeMarker {
     }
 }
 
-impl NodeTrait for NodeMarker {
+impl NodeTrait for Marker {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
@@ -202,11 +202,11 @@ impl NodeTrait for NodeMarker {
                 expanded_name!(svg "refY") => self.ref_y = attr.parse(value)?,
                 expanded_name!(svg "markerWidth") => {
                     self.width =
-                        attr.parse_and_validate(value, LengthHorizontal::check_nonnegative)?
+                        attr.parse_and_validate(value, Length::<Horizontal>::check_nonnegative)?
                 }
                 expanded_name!(svg "markerHeight") => {
                     self.height =
-                        attr.parse_and_validate(value, LengthVertical::check_nonnegative)?
+                        attr.parse_and_validate(value, Length::<Vertical>::check_nonnegative)?
                 }
                 expanded_name!(svg "orient") => self.orient = attr.parse(value)?,
                 expanded_name!(svg "preserveAspectRatio") => self.aspect = attr.parse(value)?,
@@ -592,7 +592,7 @@ fn emit_marker_by_name(
     {
         let node = acquired.get();
 
-        node.borrow().get_impl::<NodeMarker>().render(
+        node.borrow().get_impl::<Marker>().render(
             &node,
             draw_ctx,
             xpos,
