@@ -34,10 +34,10 @@ struct Common {
     vbox: Option<Option<ViewBox>>,
     preserve_aspect_ratio: Option<AspectRatio>,
     affine: Option<cairo::Matrix>,
-    x: Option<LengthHorizontal>,
-    y: Option<LengthVertical>,
-    width: Option<LengthHorizontal>,
-    height: Option<LengthVertical>,
+    x: Option<Length<Horizontal>>,
+    y: Option<Length<Vertical>>,
+    width: Option<Length<Horizontal>>,
+    height: Option<Length<Vertical>>,
 }
 
 /// State used during the pattern resolution process
@@ -50,27 +50,27 @@ struct Unresolved {
     fallback: Option<Fragment>,
 }
 
-/// Keeps track of which NodePattern provided a non-empty set of children during pattern resolution
+/// Keeps track of which Pattern provided a non-empty set of children during pattern resolution
 #[derive(Clone)]
 enum UnresolvedChildren {
-    /// Points back to the original NodePattern if it had no usable children
+    /// Points back to the original Pattern if it had no usable children
     Unresolved,
 
-    /// Points back to the original NodePattern, as no pattern in the
+    /// Points back to the original Pattern, as no pattern in the
     /// chain of fallbacks had usable children.  This only gets returned
     /// by resolve_from_defaults().
     ResolvedEmpty,
 
-    /// Points back to the NodePattern that had usable children.
+    /// Points back to the Pattern that had usable children.
     WithChildren(RsvgWeakNode),
 }
 
-/// Keeps track of which NodePattern provided a non-empty set of children during pattern resolution
+/// Keeps track of which Pattern provided a non-empty set of children during pattern resolution
 #[derive(Clone)]
 enum Children {
     Empty,
 
-    /// Points back to the NodePattern that had usable children
+    /// Points back to the Pattern that had usable children
     WithChildren(RsvgWeakNode),
 }
 
@@ -87,9 +87,8 @@ struct UnresolvedPattern {
     children: UnresolvedChildren,
 }
 
-/// Resolved pattern
 #[derive(Clone)]
-pub struct Pattern {
+pub struct ResolvedPattern {
     units: PatternUnits,
     content_units: PatternContentUnits,
     // This Option<Option<ViewBox>> is a bit strange.  We want a field
@@ -99,23 +98,23 @@ pub struct Pattern {
     vbox: Option<ViewBox>,
     preserve_aspect_ratio: AspectRatio,
     affine: cairo::Matrix,
-    x: LengthHorizontal,
-    y: LengthVertical,
-    width: LengthHorizontal,
-    height: LengthVertical,
+    x: Length<Horizontal>,
+    y: Length<Vertical>,
+    width: Length<Horizontal>,
+    height: Length<Vertical>,
 
     // Link to the node whose children are the pattern's resolved children.
     children: Children,
 }
 
 #[derive(Default)]
-pub struct NodePattern {
+pub struct Pattern {
     common: Common,
     fallback: Option<Fragment>,
-    resolved: RefCell<Option<Pattern>>,
+    resolved: RefCell<Option<ResolvedPattern>>,
 }
 
-impl NodeTrait for NodePattern {
+impl NodeTrait for Pattern {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
@@ -135,11 +134,11 @@ impl NodeTrait for NodePattern {
                 expanded_name!(svg "y") => self.common.y = Some(attr.parse(value)?),
                 expanded_name!(svg "width") => {
                     self.common.width =
-                        Some(attr.parse_and_validate(value, LengthHorizontal::check_nonnegative)?)
+                        Some(attr.parse_and_validate(value, Length::<Horizontal>::check_nonnegative)?)
                 }
                 expanded_name!(svg "height") => {
                     self.common.height =
-                        Some(attr.parse_and_validate(value, LengthVertical::check_nonnegative)?)
+                        Some(attr.parse_and_validate(value, Length::<Vertical>::check_nonnegative)?)
                 }
                 _ => (),
             }
@@ -153,8 +152,8 @@ impl NodeTrait for NodePattern {
     }
 }
 
-impl PaintSource for NodePattern {
-    type Resolved = Pattern;
+impl PaintSource for Pattern {
+    type Resolved = ResolvedPattern;
 
     fn resolve(
         &self,
@@ -184,7 +183,7 @@ impl PaintSource for NodePattern {
                         }
 
                         let borrowed_node = acquired_node.borrow();
-                        let borrowed_pattern = borrowed_node.get_impl::<NodePattern>();
+                        let borrowed_pattern = borrowed_node.get_impl::<Pattern>();
                         let unresolved = borrowed_pattern.get_unresolved(&acquired_node);
 
                         pattern = pattern.resolve_from_fallback(&unresolved.pattern);
@@ -217,7 +216,7 @@ impl PaintSource for NodePattern {
     }
 }
 
-impl AsPaintSource for Pattern {
+impl AsPaintSource for ResolvedPattern {
     fn set_as_paint_source(
         self,
         values: &ComputedValues,
@@ -408,10 +407,10 @@ impl AsPaintSource for Pattern {
 }
 
 impl UnresolvedPattern {
-    fn to_resolved(self) -> Pattern {
+    fn to_resolved(self) -> ResolvedPattern {
         assert!(self.is_resolved());
 
-        Pattern {
+        ResolvedPattern {
             units: self.common.units.unwrap(),
             content_units: self.common.content_units.unwrap(),
             vbox: self.common.vbox.unwrap(),
@@ -571,7 +570,7 @@ impl Children {
     }
 }
 
-impl NodePattern {
+impl Pattern {
     fn get_unresolved(&self, node: &RsvgNode) -> Unresolved {
         let pattern = UnresolvedPattern {
             common: self.common.clone(),
@@ -598,11 +597,11 @@ mod tests {
             &QualName::new(None, ns!(svg), local_name!("pattern")),
             None,
             None,
-            Box::new(NodePattern::default()),
+            Box::new(Pattern::default()),
         ));
 
         let borrow = node.borrow();
-        let p = borrow.get_impl::<NodePattern>();
+        let p = borrow.get_impl::<Pattern>();
         let Unresolved { pattern, .. } = p.get_unresolved(&node);
         let pattern = pattern.resolve_from_defaults();
         assert!(pattern.is_resolved());
