@@ -223,9 +223,9 @@ pub struct ComputedValues {
 }
 
 #[cfg_attr(rustfmt, rustfmt_skip)]
-pub fn parse_attribute_value_into_parsed_property(attr: &QualName, input: &mut Parser, accept_shorthands: bool) -> Result<ParsedProperty, ValueErrorKind> {
+pub fn parse_property(prop_name: &QualName, input: &mut Parser, accept_shorthands: bool) -> Result<ParsedProperty, ValueErrorKind> {
     // please keep these sorted
-    match attr.expanded() {
+    match prop_name.expanded() {
         expanded_name!(svg "baseline-shift") =>
             Ok(ParsedProperty::BaselineShift(parse_input(input)?)),
 
@@ -527,9 +527,7 @@ impl SpecifiedValues {
         let mut input = ParserInput::new(value);
         let mut parser = Parser::new(&mut input);
 
-        match parse_attribute_value_into_parsed_property(&attr, &mut parser, accept_shorthands)
-            .attribute(attr.clone())
-        {
+        match parse_property(&attr, &mut parser, accept_shorthands).attribute(attr.clone()) {
             Ok(prop) => self.set_parsed_property(&prop),
             Err(e) => {
                 // https://www.w3.org/TR/CSS2/syndata.html#unsupported-values
@@ -585,12 +583,12 @@ impl SpecifiedValues {
         declaration: &Declaration,
         important_styles: &mut HashSet<QualName>,
     ) {
-        if !declaration.important && important_styles.contains(&declaration.attribute) {
+        if !declaration.important && important_styles.contains(&declaration.prop_name) {
             return;
         }
 
         if declaration.important {
-            important_styles.insert(declaration.attribute.clone());
+            important_styles.insert(declaration.prop_name.clone());
         }
 
         self.set_parsed_property(&declaration.property);
@@ -604,14 +602,9 @@ impl SpecifiedValues {
         let mut input = ParserInput::new(declarations);
         let mut parser = Parser::new(&mut input);
 
-        let decl_parser = DeclarationListParser::new(&mut parser, DeclParser);
-
-        for decl_result in decl_parser {
-            // ignore invalid property name or value
-            if let Ok(declaration) = decl_result {
-                self.set_property_from_declaration(&declaration, important_styles)
-            }
-        }
+        DeclarationListParser::new(&mut parser, DeclParser)
+            .filter_map(Result::ok) // ignore invalid property name or value
+            .for_each(|decl| self.set_property_from_declaration(&decl, important_styles));
 
         Ok(())
     }
