@@ -113,11 +113,11 @@ fn render_ellipse(
 }
 
 #[derive(Default)]
-pub struct NodePath {
+pub struct Path {
     builder: PathBuilder,
 }
 
-impl NodeTrait for NodePath {
+impl NodeTrait for Path {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             if attr.expanded() == expanded_name!(svg "d") {
@@ -217,11 +217,11 @@ fn render_poly(
 }
 
 #[derive(Default)]
-pub struct NodePolygon {
+pub struct Polygon {
     points: Option<Points>,
 }
 
-impl NodeTrait for NodePolygon {
+impl NodeTrait for Polygon {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             if attr.expanded() == expanded_name!(svg "points") {
@@ -251,11 +251,11 @@ impl NodeTrait for NodePolygon {
 }
 
 #[derive(Default)]
-pub struct NodePolyline {
+pub struct Polyline {
     points: Option<Points>,
 }
 
-impl NodeTrait for NodePolyline {
+impl NodeTrait for Polyline {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             if attr.expanded() == expanded_name!(svg "points") {
@@ -285,14 +285,14 @@ impl NodeTrait for NodePolyline {
 }
 
 #[derive(Default)]
-pub struct NodeLine {
-    x1: LengthHorizontal,
-    y1: LengthVertical,
-    x2: LengthHorizontal,
-    y2: LengthVertical,
+pub struct Line {
+    x1: Length<Horizontal>,
+    y1: Length<Vertical>,
+    x2: Length<Horizontal>,
+    y2: Length<Vertical>,
 }
 
-impl NodeTrait for NodeLine {
+impl NodeTrait for Line {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
@@ -333,37 +333,37 @@ impl NodeTrait for NodeLine {
 }
 
 #[derive(Default)]
-pub struct NodeRect {
-    x: LengthHorizontal,
-    y: LengthVertical,
-    w: LengthHorizontal,
-    h: LengthVertical,
+pub struct Rect {
+    x: Length<Horizontal>,
+    y: Length<Vertical>,
+    w: Length<Horizontal>,
+    h: Length<Vertical>,
 
     // Radiuses for rounded corners
-    rx: Option<LengthHorizontal>,
-    ry: Option<LengthVertical>,
+    rx: Option<Length<Horizontal>>,
+    ry: Option<Length<Vertical>>,
 }
 
-impl NodeTrait for NodeRect {
+impl NodeTrait for Rect {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
                 expanded_name!(svg "x") => self.x = attr.parse(value)?,
                 expanded_name!(svg "y") => self.y = attr.parse(value)?,
                 expanded_name!(svg "width") => {
-                    self.w = attr.parse_and_validate(value, LengthHorizontal::check_nonnegative)?
+                    self.w = attr.parse_and_validate(value, Length::<Horizontal>::check_nonnegative)?
                 }
                 expanded_name!(svg "height") => {
-                    self.h = attr.parse_and_validate(value, LengthVertical::check_nonnegative)?
+                    self.h = attr.parse_and_validate(value, Length::<Vertical>::check_nonnegative)?
                 }
                 expanded_name!(svg "rx") => {
                     self.rx = attr
-                        .parse_and_validate(value, LengthHorizontal::check_nonnegative)
+                        .parse_and_validate(value, Length::<Horizontal>::check_nonnegative)
                         .map(Some)?
                 }
                 expanded_name!(svg "ry") => {
                     self.ry = attr
-                        .parse_and_validate(value, LengthVertical::check_nonnegative)
+                        .parse_and_validate(value, Length::<Vertical>::check_nonnegative)
                         .map(Some)?
                 }
                 _ => (),
@@ -554,20 +554,20 @@ impl NodeTrait for NodeRect {
 }
 
 #[derive(Default)]
-pub struct NodeCircle {
-    cx: LengthHorizontal,
-    cy: LengthVertical,
-    r: LengthBoth,
+pub struct Circle {
+    cx: Length<Horizontal>,
+    cy: Length<Vertical>,
+    r: Length<Both>,
 }
 
-impl NodeTrait for NodeCircle {
+impl NodeTrait for Circle {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
                 expanded_name!(svg "cx") => self.cx = attr.parse(value)?,
                 expanded_name!(svg "cy") => self.cy = attr.parse(value)?,
                 expanded_name!(svg "r") => {
-                    self.r = attr.parse_and_validate(value, LengthBoth::check_nonnegative)?
+                    self.r = attr.parse_and_validate(value, Length::<Both>::check_nonnegative)?
                 }
                 _ => (),
             }
@@ -596,24 +596,24 @@ impl NodeTrait for NodeCircle {
 }
 
 #[derive(Default)]
-pub struct NodeEllipse {
-    cx: LengthHorizontal,
-    cy: LengthVertical,
-    rx: LengthHorizontal,
-    ry: LengthVertical,
+pub struct Ellipse {
+    cx: Length<Horizontal>,
+    cy: Length<Vertical>,
+    rx: Length<Horizontal>,
+    ry: Length<Vertical>,
 }
 
-impl NodeTrait for NodeEllipse {
+impl NodeTrait for Ellipse {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
                 expanded_name!(svg "cx") => self.cx = attr.parse(value)?,
                 expanded_name!(svg "cy") => self.cy = attr.parse(value)?,
                 expanded_name!(svg "rx") => {
-                    self.rx = attr.parse_and_validate(value, LengthHorizontal::check_nonnegative)?
+                    self.rx = attr.parse_and_validate(value, Length::<Horizontal>::check_nonnegative)?
                 }
                 expanded_name!(svg "ry") => {
-                    self.ry = attr.parse_and_validate(value, LengthVertical::check_nonnegative)?
+                    self.ry = attr.parse_and_validate(value, Length::<Vertical>::check_nonnegative)?
                 }
                 _ => (),
             }
