@@ -18,9 +18,9 @@ use crate::rect::RectangleExt;
 use crate::viewbox::*;
 
 #[derive(Default)]
-pub struct NodeGroup();
+pub struct Group();
 
-impl NodeTrait for NodeGroup {
+impl NodeTrait for Group {
     fn set_atts(&mut self, _: Option<&RsvgNode>, _: &PropertyBag<'_>) -> NodeResult {
         Ok(())
     }
@@ -45,18 +45,18 @@ impl NodeTrait for NodeGroup {
 /// Sometimes we just need a node that can contain children, but doesn't
 /// render itself or its children.  This is just that kind of node.
 #[derive(Default)]
-pub struct NodeNonRendering;
+pub struct NonRendering;
 
-impl NodeTrait for NodeNonRendering {
+impl NodeTrait for NonRendering {
     fn set_atts(&mut self, _: Option<&RsvgNode>, _: &PropertyBag<'_>) -> NodeResult {
         Ok(())
     }
 }
 
 #[derive(Default)]
-pub struct NodeSwitch();
+pub struct Switch();
 
-impl NodeTrait for NodeSwitch {
+impl NodeTrait for Switch {
     fn set_atts(&mut self, _: Option<&RsvgNode>, _: &PropertyBag<'_>) -> NodeResult {
         Ok(())
     }
@@ -87,22 +87,22 @@ impl NodeTrait for NodeSwitch {
 /// Intrinsic dimensions of an SVG document fragment
 #[derive(Debug, Copy, Clone, PartialEq)]
 pub struct IntrinsicDimensions {
-    pub width: Option<LengthHorizontal>,
-    pub height: Option<LengthVertical>,
+    pub width: Option<Length<Horizontal>>,
+    pub height: Option<Length<Vertical>>,
     pub vbox: Option<ViewBox>,
 }
 
 #[derive(Default)]
-pub struct NodeSvg {
+pub struct Svg {
     preserve_aspect_ratio: AspectRatio,
-    x: Option<LengthHorizontal>,
-    y: Option<LengthVertical>,
-    w: Option<LengthHorizontal>,
-    h: Option<LengthVertical>,
+    x: Option<Length<Horizontal>>,
+    y: Option<Length<Vertical>>,
+    w: Option<Length<Horizontal>>,
+    h: Option<Length<Vertical>>,
     vbox: Option<ViewBox>,
 }
 
-impl NodeSvg {
+impl Svg {
     pub fn get_size(&self, values: &ComputedValues, dpi: Dpi) -> Option<(i32, i32)> {
         let (_, _, w, h) = self.get_unnormalized_viewport();
 
@@ -116,7 +116,7 @@ impl NodeSvg {
                 ))
             }
 
-            (w, h, None) if w.unit() != LengthUnit::Percent && h.unit() != LengthUnit::Percent => {
+            (w, h, None) if w.unit != LengthUnit::Percent && h.unit != LengthUnit::Percent => {
                 let params = ViewParams::new(dpi.x(), dpi.y(), 0.0, 0.0);
 
                 Some((
@@ -130,8 +130,8 @@ impl NodeSvg {
 
     pub fn get_intrinsic_dimensions(&self) -> IntrinsicDimensions {
         IntrinsicDimensions {
-            width: self.w,
-            height: self.h,
+            width: self.w.map(Into::into),
+            height: self.h.map(Into::into),
             vbox: self.vbox,
         }
     }
@@ -140,24 +140,24 @@ impl NodeSvg {
     fn get_unnormalized_viewport(
         &self,
     ) -> (
-        LengthHorizontal,
-        LengthVertical,
-        LengthHorizontal,
-        LengthVertical,
+        Length<Horizontal>,
+        Length<Vertical>,
+        Length<Horizontal>,
+        Length<Vertical>,
     ) {
         // these defaults are per the spec
         let x = self
             .x
-            .unwrap_or_else(|| LengthHorizontal::parse_str("0").unwrap());
+            .unwrap_or_else(|| Length::<Horizontal>::parse_str("0").unwrap());
         let y = self
             .y
-            .unwrap_or_else(|| LengthVertical::parse_str("0").unwrap());
+            .unwrap_or_else(|| Length::<Vertical>::parse_str("0").unwrap());
         let w = self
             .w
-            .unwrap_or_else(|| LengthHorizontal::parse_str("100%").unwrap());
+            .unwrap_or_else(|| Length::<Horizontal>::parse_str("100%").unwrap());
         let h = self
             .h
-            .unwrap_or_else(|| LengthVertical::parse_str("100%").unwrap());
+            .unwrap_or_else(|| Length::<Vertical>::parse_str("100%").unwrap());
 
         (x, y, w, h)
     }
@@ -174,7 +174,7 @@ impl NodeSvg {
     }
 }
 
-impl NodeTrait for NodeSvg {
+impl NodeTrait for Svg {
     fn set_atts(&mut self, parent: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         // x & y attributes have no effect on outermost svg
         // http://www.w3.org/TR/SVG/struct.html#SVGElement
@@ -189,11 +189,11 @@ impl NodeTrait for NodeSvg {
                 expanded_name!(svg "y") if is_inner_svg => self.y = Some(attr.parse(value)?),
                 expanded_name!(svg "width") => {
                     self.w =
-                        Some(attr.parse_and_validate(value, LengthHorizontal::check_nonnegative)?)
+                        Some(attr.parse_and_validate(value, Length::<Horizontal>::check_nonnegative)?)
                 }
                 expanded_name!(svg "height") => {
                     self.h =
-                        Some(attr.parse_and_validate(value, LengthVertical::check_nonnegative)?)
+                        Some(attr.parse_and_validate(value, Length::<Vertical>::check_nonnegative)?)
                 }
                 expanded_name!(svg "viewBox") => self.vbox = attr.parse(value).map(Some)?,
                 _ => (),
@@ -264,15 +264,15 @@ impl NodeTrait for NodeSvg {
 }
 
 #[derive(Default)]
-pub struct NodeUse {
+pub struct Use {
     link: Option<Fragment>,
-    x: LengthHorizontal,
-    y: LengthVertical,
-    w: Option<LengthHorizontal>,
-    h: Option<LengthVertical>,
+    x: Length<Horizontal>,
+    y: Length<Vertical>,
+    w: Option<Length<Horizontal>>,
+    h: Option<Length<Vertical>>,
 }
 
-impl NodeTrait for NodeUse {
+impl NodeTrait for Use {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
@@ -283,12 +283,12 @@ impl NodeTrait for NodeUse {
                 expanded_name!(svg "y") => self.y = attr.parse(value)?,
                 expanded_name!(svg "width") => {
                     self.w = attr
-                        .parse_and_validate(value, LengthHorizontal::check_nonnegative)
+                        .parse_and_validate(value, Length::<Horizontal>::check_nonnegative)
                         .map(Some)?
                 }
                 expanded_name!(svg "height") => {
                     self.h = attr
-                        .parse_and_validate(value, LengthVertical::check_nonnegative)
+                        .parse_and_validate(value, Length::<Vertical>::check_nonnegative)
                         .map(Some)?
                 }
                 _ => (),
@@ -363,11 +363,11 @@ impl NodeTrait for NodeUse {
 
         let nw = self
             .w
-            .unwrap_or_else(|| LengthHorizontal::parse_str("100%").unwrap())
+            .unwrap_or_else(|| Length::<Horizontal>::parse_str("100%").unwrap())
             .normalize(values, &params);
         let nh = self
             .h
-            .unwrap_or_else(|| LengthVertical::parse_str("100%").unwrap())
+            .unwrap_or_else(|| Length::<Vertical>::parse_str("100%").unwrap())
             .normalize(values, &params);
 
         // width or height set to 0 disables rendering of the element
@@ -391,7 +391,7 @@ impl NodeTrait for NodeUse {
             })
         } else {
             let node_data = child.borrow();
-            let symbol = node_data.get_impl::<NodeSymbol>();
+            let symbol = node_data.get_impl::<Symbol>();
 
             let clip_mode = if !values.is_overflow()
                 || (values.overflow == Overflow::Visible && child.borrow().is_overflow())
@@ -420,12 +420,12 @@ impl NodeTrait for NodeUse {
 }
 
 #[derive(Default)]
-pub struct NodeSymbol {
+pub struct Symbol {
     preserve_aspect_ratio: AspectRatio,
     vbox: Option<ViewBox>,
 }
 
-impl NodeTrait for NodeSymbol {
+impl NodeTrait for Symbol {
     fn set_atts(&mut self, _parent: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
