@@ -45,15 +45,15 @@ use crate::space::{xml_space_normalize, NormalizeDefault, XmlSpaceNormalize};
 /// [text chunk]: https://www.w3.org/TR/SVG11/text.html#TextLayoutIntroduction
 struct Chunk {
     values: ComputedValues,
-    x: Option<LengthHorizontal>,
-    y: Option<LengthVertical>,
+    x: Option<Length<Horizontal>>,
+    y: Option<Length<Vertical>>,
     spans: Vec<Span>,
 }
 
 struct MeasuredChunk {
     values: ComputedValues,
-    x: Option<LengthHorizontal>,
-    y: Option<LengthVertical>,
+    x: Option<Length<Horizontal>>,
+    y: Option<Length<Vertical>>,
     advance: (f64, f64),
     spans: Vec<MeasuredSpan>,
 }
@@ -67,8 +67,8 @@ struct PositionedChunk {
 struct Span {
     values: ComputedValues,
     text: String,
-    dx: Option<LengthHorizontal>,
-    dy: Option<LengthVertical>,
+    dx: Option<Length<Horizontal>>,
+    dy: Option<Length<Vertical>>,
     _depth: usize,
 }
 
@@ -77,8 +77,8 @@ struct MeasuredSpan {
     layout: pango::Layout,
     _layout_size: (f64, f64),
     advance: (f64, f64),
-    dx: Option<LengthHorizontal>,
-    dy: Option<LengthVertical>,
+    dx: Option<Length<Horizontal>>,
+    dy: Option<Length<Vertical>>,
 }
 
 struct PositionedSpan {
@@ -93,8 +93,8 @@ struct PositionedSpan {
 impl Chunk {
     fn new(
         values: &ComputedValues,
-        x: Option<LengthHorizontal>,
-        y: Option<LengthVertical>,
+        x: Option<Length<Horizontal>>,
+        y: Option<Length<Vertical>>,
     ) -> Chunk {
         Chunk {
             values: values.clone(),
@@ -190,8 +190,8 @@ impl Span {
     fn new(
         text: &str,
         values: ComputedValues,
-        dx: Option<LengthHorizontal>,
-        dy: Option<LengthVertical>,
+        dx: Option<Length<Horizontal>>,
+        dy: Option<Length<Vertical>>,
         depth: usize,
     ) -> Span {
         Span {
@@ -422,8 +422,8 @@ fn children_to_chunks(
     node: &RsvgNode,
     cascaded: &CascadedValues<'_>,
     draw_ctx: &mut DrawingCtx,
-    dx: Option<LengthHorizontal>,
-    dy: Option<LengthVertical>,
+    dx: Option<Length<Horizontal>>,
+    dy: Option<Length<Vertical>>,
     depth: usize,
 ) {
     for child in node.children() {
@@ -438,7 +438,7 @@ fn children_to_chunks(
 
             NodeType::TSpan => {
                 let cascaded = CascadedValues::new(cascaded, &child);
-                child.borrow().get_impl::<NodeTSpan>().to_chunks(
+                child.borrow().get_impl::<TSpan>().to_chunks(
                     &child,
                     &cascaded,
                     draw_ctx,
@@ -449,7 +449,7 @@ fn children_to_chunks(
 
             NodeType::TRef => {
                 let cascaded = CascadedValues::new(cascaded, &child);
-                child.borrow().get_impl::<NodeTRef>().to_chunks(
+                child.borrow().get_impl::<TRef>().to_chunks(
                     &child,
                     &cascaded,
                     draw_ctx,
@@ -464,7 +464,7 @@ fn children_to_chunks(
 }
 
 /// In SVG text elements, we use `NodeChars` to store character data.  For example,
-/// an element like `<text>Foo Bar</text>` will be a `NodeText` with a single child,
+/// an element like `<text>Foo Bar</text>` will be a `Text` with a single child,
 /// and the child will be a `NodeChars` with "Foo Bar" for its contents.
 ///
 /// Text elements can contain `<tspan>` sub-elements.  In this case,
@@ -499,8 +499,8 @@ impl NodeChars {
         }
     }
 
-    pub fn get_string(&self) -> String {
-        self.string.borrow().clone()
+    pub fn is_empty(&self) -> bool {
+        self.string.borrow().is_empty()
     }
 
     pub fn append(&self, s: &str) {
@@ -529,8 +529,8 @@ impl NodeChars {
         &self,
         node: &RsvgNode,
         values: &ComputedValues,
-        dx: Option<LengthHorizontal>,
-        dy: Option<LengthVertical>,
+        dx: Option<Length<Horizontal>>,
+        dy: Option<Length<Vertical>>,
         depth: usize,
     ) -> Span {
         self.ensure_normalized_string(node, values);
@@ -549,8 +549,8 @@ impl NodeChars {
         node: &RsvgNode,
         values: &ComputedValues,
         chunks: &mut Vec<Chunk>,
-        dx: Option<LengthHorizontal>,
-        dy: Option<LengthVertical>,
+        dx: Option<Length<Horizontal>>,
+        dy: Option<Length<Vertical>>,
         depth: usize,
     ) {
         let span = self.make_span(&node, values, dx, dy, depth);
@@ -560,6 +560,10 @@ impl NodeChars {
 
         chunks[num_chunks - 1].spans.push(span);
     }
+
+    pub fn get_string(&self) -> String {
+        self.string.borrow().clone()
+    }
 }
 
 impl NodeTrait for NodeChars {
@@ -569,14 +573,14 @@ impl NodeTrait for NodeChars {
 }
 
 #[derive(Default)]
-pub struct NodeText {
-    x: LengthHorizontal,
-    y: LengthVertical,
-    dx: Option<LengthHorizontal>,
-    dy: Option<LengthVertical>,
+pub struct Text {
+    x: Length<Horizontal>,
+    y: Length<Vertical>,
+    dx: Option<Length<Horizontal>>,
+    dy: Option<Length<Vertical>>,
 }
 
-impl NodeText {
+impl Text {
     fn make_chunks(
         &self,
         node: &RsvgNode,
@@ -590,7 +594,7 @@ impl NodeText {
     }
 }
 
-impl NodeTrait for NodeText {
+impl NodeTrait for Text {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
@@ -658,11 +662,11 @@ impl NodeTrait for NodeText {
 }
 
 #[derive(Default)]
-pub struct NodeTRef {
+pub struct TRef {
     link: Option<Fragment>,
 }
 
-impl NodeTRef {
+impl TRef {
     fn to_chunks(
         &self,
         node: &RsvgNode,
@@ -708,7 +712,7 @@ fn extract_chars_children_to_chunks_recursively(
     }
 }
 
-impl NodeTrait for NodeTRef {
+impl NodeTrait for TRef {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
@@ -724,14 +728,14 @@ impl NodeTrait for NodeTRef {
 }
 
 #[derive(Default)]
-pub struct NodeTSpan {
-    x: Option<LengthHorizontal>,
-    y: Option<LengthVertical>,
-    dx: Option<LengthHorizontal>,
-    dy: Option<LengthVertical>,
+pub struct TSpan {
+    x: Option<Length<Horizontal>>,
+    y: Option<Length<Vertical>>,
+    dx: Option<Length<Horizontal>>,
+    dy: Option<Length<Vertical>>,
 }
 
-impl NodeTSpan {
+impl TSpan {
     fn to_chunks(
         &self,
         node: &RsvgNode,
@@ -750,7 +754,7 @@ impl NodeTSpan {
     }
 }
 
-impl NodeTrait for NodeTSpan {
+impl NodeTrait for TSpan {
     fn set_atts(&mut self, _: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
