@@ -2,7 +2,7 @@ use crate::xml_rs::{reader::XmlEvent, ParserConfig};
 use encoding::label::encoding_from_whatwg_label;
 use encoding::DecoderTrap;
 use libc;
-use markup5ever::{ExpandedName, LocalName, Namespace, QualName};
+use markup5ever::{expanded_name, local_name, namespace_url, ns, ExpandedName, LocalName, Namespace, QualName};
 use std::cell::RefCell;
 use std::collections::HashMap;
 use std::rc::{Rc, Weak};
@@ -11,12 +11,12 @@ use std::str;
 use crate::allowed_url::AllowedUrl;
 use crate::document::{Document, DocumentBuilder};
 use crate::error::LoadingError;
-use crate::handle::LoadOptions;
 use crate::io::{self, get_input_stream_for_loading};
 use crate::limits::MAX_LOADED_ELEMENTS;
 use crate::node::{NodeType, RsvgNode};
 use crate::property_bag::PropertyBag;
-use crate::style::NodeStyle;
+use crate::style::{Style, StyleType};
+use crate::text::NodeChars;
 use crate::xml2_load::{ParseFromStreamError, Xml2Parser};
 
 #[derive(Clone)]
@@ -27,6 +27,12 @@ enum Context {
     // Creating nodes for elements under the current node
     ElementCreation,
 
+    // Inside <style>; accumulate text to include in a stylesheet
+    Style,
+
+    // An unsupported element inside a `<style>` element, to be ignored
+    UnsupportedStyleChild,
+
     // Inside <xi:include>
     XInclude(XIncludeContext),
 
@@ -45,6 +51,12 @@ struct XIncludeContext {
     need_fallback: bool,
 }
 
+/// Accumulates data inside a `<style>` element
+#[derive(Clone)]
+struct StyleContext {
+    text: String,
+}
+
 // This is to hold an xmlEntityPtr from libxml2; we just hold an opaque pointer
 // that is freed in impl Drop for XmlState
 type XmlEntityPtr = *mut libc::c_void;
@@ -90,7 +102,7 @@ struct XmlStateInner {
 pub struct XmlState {
     inner: RefCell<XmlStateInner>,
 
-    load_options: LoadOptions,
+    unlimited_size: bool,
 }
 
 /// Errors returned from XmlState::acquire()
@@ -113,18 +125,18 @@ impl XmlStateInner {
 }
 
 impl XmlState {
-    fn new(load_options: &LoadOptions) -> XmlState {
+    fn new(document_builder: DocumentBuilder, unlimited_size: bool) -> XmlState {
         XmlState {
             inner: RefCell::new(XmlStateInner {
                 weak: None,
-                document_builder: Some(DocumentBuilder::new(load_options)),
+                document_builder: Some(document_builder),
                 num_loaded_elements: 0,
                 context_stack: vec![Context::Start],
                 current_node: None,
                 entities: HashMap::new(),
             }),
 
-            load_options: load_options.clone(),
+            unlimited_size,
         }
     }
 
@@ -163,6 +175,10 @@ impl XmlState {
         let new_context = match context {
             Context::Start => self.element_creation_start_element(&name, pbag),
             Context::ElementCreation => self.element_creation_start_element(&name, pbag),
+
+            Context::Style => self.inside_style_start_element(&name),
+            Context::UnsupportedStyleChild => self.unsupported_style_start_element(&name),
+
             Context::XInclude(ref ctx) => self.inside_xinclude_start_element(&ctx, &name),
             Context::UnsupportedXIncludeChild => self.unsupported_xinclude_start_element(&name),
             Context::XIncludeFallback(ref ctx) => {
@@ -183,9 +199,14 @@ impl XmlState {
         match context {
             Context::Start => panic!("end_element: XML handler stack is empty!?"),
             Context::ElementCreation => self.element_creation_end_element(),
+
+            Context::Style => self.style_end_element(),
+            Context::UnsupportedStyleChild => (),
+
             Context::XInclude(_) => (),
             Context::UnsupportedXIncludeChild => (),
             Context::XIncludeFallback(_) => (),
+
             Context::FatalError(_) => return,
         }
 
@@ -197,14 +218,19 @@ impl XmlState {
         let context = self.inner.borrow().context();
 
         match context {
-            // This is character data before the first element, i.e. something like
-            //  <?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg"/>
-            // ^ note the space here
-            // libxml2 is not finished reading the file yet; it will emit an error
-            // on its own when it finishes.  So, ignore this condition.
-            Context::Start => (),
+            Context::Start => {
+                // This is character data before the first element, i.e. something like
+                //  <?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg"/>
+                // ^ note the space here
+                // libxml2 is not finished reading the file yet; it will emit an error
+                // on its own when it finishes.  So, ignore this condition.
+            }
 
             Context::ElementCreation => self.element_creation_characters(text),
+
+            Context::Style => self.element_creation_characters(text),
+            Context::UnsupportedStyleChild => (),
+
             Context::XInclude(_) => (),
             Context::UnsupportedXIncludeChild => (),
             Context::XIncludeFallback(ref ctx) => self.xinclude_fallback_characters(&ctx, text),
@@ -231,21 +257,22 @@ impl XmlState {
                 }
             }
 
-            if (alternate == None || alternate.as_ref().map(String::as_str) == Some("no"))
-                && type_.as_ref().map(String::as_str) == Some("text/css")
-                && href.is_some()
-            {
-                let mut inner = self.inner.borrow_mut();
+            let mut inner = self.inner.borrow_mut();
 
-                if let Ok(aurl) =
-                    AllowedUrl::from_href(&href.unwrap(), self.load_options.base_url.as_ref())
+            if let Some(href) = href {
+                // FIXME: https://www.w3.org/TR/xml-stylesheet/ does not seem to specify
+                // what to do if the stylesheet cannot be loaded, so here we ignore the error.
+                if inner
+                    .document_builder
+                    .as_mut()
+                    .unwrap()
+                    .append_stylesheet_from_xml_processing_instruction(alternate, type_, &href)
+                    .is_err()
                 {
-                    inner.document_builder.as_mut().unwrap().load_css(&aurl);
-                } else {
-                    self.error(ParseFromStreamError::XmlParseError(String::from(
-                        "disallowed URL in xml-stylesheet",
-                    )));
+                    rsvg_log!("invalid xml-stylesheet {} in XML processing instruction", href);
                 }
+            } else {
+                rsvg_log!("xml-stylesheet processing instruction does not have href; ignoring");
             }
         } else {
             self.error(ParseFromStreamError::XmlParseError(String::from(
@@ -291,24 +318,17 @@ impl XmlState {
                 .append_element(name, pbag, parent);
             inner.current_node = Some(node);
 
-            Context::ElementCreation
+            if name.expanded() == expanded_name!(svg "style") {
+                Context::Style
+            } else {
+                Context::ElementCreation
+            }
         }
     }
 
     fn element_creation_end_element(&self) {
         let mut inner = self.inner.borrow_mut();
-
         let node = inner.current_node.take().unwrap();
-
-        if node.borrow().get_type() == NodeType::Style {
-            let css_data = node.borrow().get_impl::<NodeStyle>().get_css(&node);
-            inner
-                .document_builder
-                .as_mut()
-                .unwrap()
-                .parse_css(&css_data);
-        }
-
         inner.current_node = node.parent();
     }
 
@@ -323,6 +343,46 @@ impl XmlState {
             .append_characters(text, &mut parent);
     }
 
+    fn style_end_element(&self) {
+        self.add_inline_stylesheet();
+        self.element_creation_end_element()
+    }
+
+    fn add_inline_stylesheet(&self) {
+        let mut inner = self.inner.borrow_mut();
+        let current_node = inner.current_node.as_ref().unwrap();
+
+        assert!(current_node.borrow().get_type() == NodeType::Style);
+
+        let style_type = current_node
+            .borrow()
+            .get_impl::<Style>()
+            .style_type()
+            .unwrap_or(StyleType::TextCss);
+
+        if style_type == StyleType::TextCss {
+            let stylesheet_text = current_node.children()
+                .map(|child| {
+                    let child_borrow = child.borrow();
+
+                    assert!(child_borrow.get_type() == NodeType::Chars);
+                    child_borrow.get_impl::<NodeChars>().get_string()
+                })
+                .collect::<String>();
+
+            let builder = inner.document_builder.as_mut().unwrap();
+            builder.append_stylesheet_from_text(&stylesheet_text);
+        }
+    }
+
+    fn inside_style_start_element(&self, name: &QualName) -> Context {
+        self.unsupported_style_start_element(name)
+    }
+
+    fn unsupported_style_start_element(&self, _name: &QualName) -> Context {
+        Context::UnsupportedStyleChild
+    }
+
     fn xinclude_start_element(&self, _name: &QualName, pbag: &PropertyBag) -> Context {
         let mut href = None;
         let mut parse = None;
@@ -400,8 +460,14 @@ impl XmlState {
         encoding: Option<&str>,
     ) -> Result<(), AcquireError> {
         if let Some(href) = href {
-            let aurl =
-                AllowedUrl::from_href(href, self.load_options.base_url.as_ref()).map_err(|e| {
+            let aurl = self
+                .inner
+                .borrow()
+                .document_builder
+                .as_ref()
+                .unwrap()
+                .resolve_href(href)
+                .map_err(|e| {
                     // FIXME: should AlloweUrlError::HrefParseError be a fatal error,
                     // not a resource error?
                     rsvg_log!("could not acquire \"{}\": {}", href, e);
@@ -498,14 +564,9 @@ impl XmlState {
             .unwrap()
             .upgrade()
             .unwrap();
-        Xml2Parser::from_stream(
-            strong,
-            self.load_options.unlimited_size,
-            stream,
-            cancellable,
-        )
-        .and_then(|parser| parser.parse())
-        .and_then(|_: ()| self.check_last_error())
+        Xml2Parser::from_stream(strong, self.unlimited_size, stream, cancellable)
+            .and_then(|parser| parser.parse())
+            .and_then(|_: ()| self.check_last_error())
     }
 
     fn unsupported_xinclude_start_element(&self, _name: &QualName) -> Context {
@@ -574,11 +635,12 @@ fn parse_xml_stylesheet_processing_instruction(data: &str) -> Result<Vec<(String
 }
 
 pub fn xml_load_from_possibly_compressed_stream(
-    load_options: &LoadOptions,
+    document_builder: DocumentBuilder,
+    unlimited_size: bool,
     stream: &gio::InputStream,
     cancellable: Option<&gio::Cancellable>,
 ) -> Result<Document, LoadingError> {
-    let state = Rc::new(XmlState::new(load_options));
+    let state = Rc::new(XmlState::new(document_builder, unlimited_size));
 
     state.inner.borrow_mut().weak = Some(Rc::downgrade(&state));
 
